# chronpy

[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/astro-chronpy?color=blue&logo=Python&logoColor=white&style=for-the-badge)](https://pypi.org/project/astro-chronpy)
[![PyPI - Version](https://img.shields.io/pypi/v/astro-chronpy?color=blue&logo=PyPI&logoColor=white&style=for-the-badge)](https://pypi.org/project/chron-py)
[![License: GPL v3](https://img.shields.io/github/license/wcxve/chronpy?color=blue&logo=open-source-initiative&logoColor=white&style=for-the-badge)](https://www.gnu.org/licenses/gpl-3.0)<br>
[![Coverage Status](https://img.shields.io/coverallsCoverage/github/wcxve/chronpy?logo=Coveralls&logoColor=white&style=for-the-badge)](https://coveralls.io/github/wcxve/chronpy)
[![Documentation Status](https://img.shields.io/readthedocs/chronpy?logo=Read-the-Docs&logoColor=white&style=for-the-badge)](https://chronpy.readthedocs.io/en/latest/?badge=latest)

-----

## Installation

```console
pip install astro-chronpy
```

## License

`chronpy` is distributed under the terms of the [GPL-3.0](https://www.gnu.org/licenses/gpl-3.0-standalone.html) license.

```{toctree}
:maxdepth: 2
:hidden:

api
GitHub Repository <https://github.com/wcxve/chronpy>
```
